@@ -10,8 +10,9 @@ csvScopus2df <- function(file){
     #D <- rio::import(file[i], quote='"')
     #D <- read.csv(file[i], quote='"', check.names = F, stringsAsFactors = F)
 
-    D <- read_csv(file[i], na=character(), quote='"', trim_ws = FALSE, progress = show_progress()) %>%
-      mutate(across(!where(is.numeric), as.character)) %>% 
+    D <- read_csv(file[i], na=character(), quote='"', trim_ws = FALSE, progress = show_progress(),
+                  col_types = cols(.default = col_character())) %>%  # Introduced to remove cols parsing errors
+      #mutate(across(!where(is.numeric), as.character)) %>%   # not yet necessary with the inclusion of previuos line
       mutate(across(where(is.character), tidyr::replace_na,"")) %>% as.data.frame(stringsAsFactors=FALSE)
     
     if (i>1){
@@ -32,12 +33,17 @@ csvScopus2df <- function(file){
   DATA$AU=gsub(",", ";", DATA$AU)
   
   # Affiliation
-  DATA$C1 <- unlist(lapply(strsplit(DATA$C1,";"), function(l){
-    l <- paste(gsub(".*\\., ","",l), collapse=";",sep="")
-  }))
-
+  if (!("C1" %in% names(DATA))){DATA$C1 <- NA}else{
+    DATA$C1 <- unlist(lapply(strsplit(DATA$C1,";"), function(l){
+      l <- paste(gsub(".*\\., ","",l), collapse=";",sep="")
+    }))
+  }
   # Iso Source Titles
-  DATA$J9 <- gsub("\\.","",DATA$JI)
+  if ("JI" %in% names(DATA)){
+    DATA$J9 <- gsub("\\.","",DATA$JI)
+    }else{
+      DATA$J9 <- DATA$JI <- DATA$SO
+    }
  
   DI <- DATA$DI
   URL <- DATA$URL
@@ -55,10 +61,13 @@ labelling <- function(DATA){
   label <- names(DATA)
   label <- gsub("Abbreviated Source Title","JI",label)
   label <- gsub("Authors with affiliations","C1",label)
+  label <- gsub("Author Addresses","C1",label)
   #label <- gsub("Affiliations","RP",label)
   label <- gsub("Authors","AU",label)
+  label <- gsub("Author Names","AU",label)
   label <- gsub("Source title","SO",label)
   label <- gsub("Title","TI",label)
+  label <- gsub("Publication Year","PY",label)
   label <- gsub("Year","PY",label)
   label <- gsub("Volume","VL",label)
   label <- gsub("Issue","IS",label)
